@@ -5,7 +5,7 @@
 #    |_|_|_|_|_||_|_\__,_|_.__/
 #    simple python object store
 #
-# Copyright 2009-2010, 2014-2022 Thomas Perl <thp.io>. All rights reserved.
+# Copyright 2009-2010, 2014-2022, 2024 Thomas Perl <thp.io>. All rights reserved.
 #
 # Permission to use, copy, modify, and/or distribute this software for any
 # purpose with or without fee is hereby granted, provided that the above
@@ -36,7 +36,7 @@ import logging
 
 
 __author__ = 'Thomas Perl <m@thp.io>'
-__version__ = '2.0.7'
+__version__ = '2.0.8'
 __url__ = 'http://thp.io/2010/minidb/'
 __license__ = 'ISC'
 
@@ -412,7 +412,7 @@ class Store(object):
                     type_ = attr_to_type.get(name, None)
                     yield (self.deserialize(value, type_) if type_ is not None else value)
 
-            return (RowProxy(tuple(_decode(row, columns)), columns) for row in result)
+            return (RowProxy(tuple(_decode(row, columns)), columns) for row in list(result))
 
     def load(self, class_, *args, **kwargs):
         with self.lock:
